@@ -1,5 +1,8 @@
 from enum import Enum as _Enum
 
+SHARED_CACHE = ['computation_id', 'mode', 'epochs', 'num_folds', 'patience', 'score_delta',
+                'validation_epochs']
+
 
 class Phase(str, _Enum):
     INIT_RUNS = 'init_runs'
